@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: apache.tcl,v 1.5 1999/01/31 11:04:52 jfontain Exp $}
+set rcsId {$Id: apache.tcl,v 1.6 1999/02/03 21:05:01 jfontain Exp $}
 
 package provide apache 1.1
 package require apacheutilities
@@ -91,25 +91,4 @@ namespace eval apache {
         incr data(updates)
     }
 
-    proc formattedTime {seconds} {
-        set string {}
-        set interval [expr {$seconds/86400}]                                                                                 ;# days
-        if {$interval>0} {
-            append string ${interval}d
-            set seconds [expr {$seconds%86400}]
-        }
-        set interval [expr {$seconds/3600}]                                                                                 ;# hours
-        if {$interval>0} {
-            append string ${interval}h
-            set seconds [expr {$seconds%3600}]
-        }
-        set interval [expr {$seconds/60}]                                                                                 ;# minutes
-        if {$interval>0} {
-            append string ${interval}m
-            set seconds [expr {$seconds%60}]
-        }
-        append string ${seconds}s
-        return $string
-    }
-
 }
