@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: canvhand.tcl,v 1.25 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: canvhand.tcl,v 1.26 1999/01/29 21:52:31 jfontain Exp $}
 
 class canvasWindowManager {
 
@@ -43,7 +43,7 @@ class canvasWindowManager {
             resize $this [winfo width $widget::($this,path)] [winfo height $widget::($this,path)]             ;# recalculate handles
         }
 
-        proc set-path {this value} {
+        proc set-path {this value} {  ;### mandatory construction time option: eventually enforce or make a constructor argument ###
             if {![winfo exists $value]} {
                 error "invalid widget: \"$value\""
             }
