@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: cpustats.tcl,v 1.17 1999/01/23 21:20:10 jfontain Exp $}
+set rcsId {$Id: cpustats.tcl,v 1.18 1999/02/26 21:07:39 jfontain Exp $}
 
 
-package provide cpustats 1.3
+package provide cpustats 1.4
 package require network 1.2
 
 namespace eval cpustats {
@@ -46,8 +46,11 @@ $ moodss ps --remote foo.bar.com
         if {![catch {set locator $options(--remote)}]||![catch {set locator $options(-r)}]} {                   ;# remote monitoring
             set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
             foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
-            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /proc/stat; echo $?}]!=0} {
-                puts stderr "on remote host $remote(host) as user $remote(user), /proc/stat is not readable"
+            set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/stat"]
+            fileevent $file readable {set ::cpustats::remote(busy) 0}
+            vwait ::cpustats::remote(busy)
+            if {[catch {close $file} message]} {
+                puts stderr "on remote host $remote(host) as user $remote(user): $message"
                 exit 1                                                                                        ;# detect errors early
             }
         } else {
@@ -65,9 +68,18 @@ $ moodss ps --remote foo.bar.com
         variable data
 
         if {[info exists remote]} {
-            set statisticsFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/stat"]
+            if {![info exists statisticsFile]} {                           ;# start data gathering process in a non blocking fashion
+                if {$remote(busy)} return                                           ;# core invocation while waiting for remote data
+                set remote(busy) 1
+                set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/stat"]
+                # do not hang GUI, allow other modules updates
+                fileevent $file readable "set ::cpustats::statisticsFile $file; ::cpustats::update"
+                return                                                                                       ;# wait for remote data
+            }                                                                                 ;# else continue below to process data
             gets $statisticsFile line
             close $statisticsFile                                                   ;# closing is necessary since seek does not work
+            unset statisticsFile
+            set remote(busy) 0
         } else {
             seek $statisticsFile 0                                                                  ;# rewind before retrieving data
             gets $statisticsFile line
