@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: help.tcl,v 1.28 1999/01/10 21:24:43 jfontain Exp $}
+set rcsId {$Id: help.tcl,v 1.29 1999/01/16 16:18:06 jfontain Exp $}
 
 namespace eval help {
 
@@ -130,21 +130,6 @@ proc aboutDialogBox {} {
     dialogBox::display $dialog $frame
 }
 
-proc modulesHelpDialogBox {args} {                                                                     ;# arguments are module names
-    foreach module $args {
-        append text "$module module (version [package provide $module])"
-        if {[string length $modules::($module,arguments)]>0} {
-            append text ", (invoked with arguments: $modules::($module,arguments))"
-        }
-        append text ":\n"
-        if {[catch {append text [set ${module}::data(helpText)]}]} {
-             append text "\nno help available\n"
-        }
-        append text \n
-    }
-    simpleTextDialogBox {moodss: Modules Help} $text
-}
-
 proc versionsDialogBox {} {
     array set ::versionsData {
         updates 0
