@@ -146,7 +146,7 @@ rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jf
 for installation. It requires the tcl, tk, blt and tktable rpms (see INSTALL
 file for more information). Unless you want to work on the moodss source
 code, you can skip the rest of this section.
-<P>For the current version (6.3), the following packages must be installed
+<P>For the current version (6.4), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -227,10 +227,13 @@ time, so that an identical dashboard can be relaunched at will.
 
 <H4>
 <A NAME="userinterface"></A>5.1. User interface</H4>
-Soon after the application launch, tabular data is displayed in one or
-more tkTable widgets with automatic scroll bars, between the menu bar,
-the drop sites with graphical viewers, summary table, free text and trash
-icons and a message area, as one can see below:
+Immediately after launch, module(s) is(are) loaded and initialized, with
+corresponding messages displayed in the message area, as follows:
+<CENTER><PRE><IMG SRC="moodss5.gif" HEIGHT=54 WIDTH=234></PRE></CENTER>
+Soon after, tabular data is displayed in one or more tkTable widgets with
+automatic scroll bars, between the menu bar, the drop sites with graphical
+viewers, summary table, free text and trash icons and a message area, as
+one can see below:
 <CENTER><PRE><IMG SRC="moodss1.gif" ALT="moodss initial main window view" NOSAVE HEIGHT=501 WIDTH=501></PRE></CENTER>
 The message area is used to display status information, such as when the
 data is being updated, and help information, as the user moves the mouse
