@@ -5,6 +5,8 @@ exec wish "$0" "$@"
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
+set applicationVersion 6.4
+
 proc recordRCSId {variableName empty operation} {
     foreach {header file version} $::rcsId break
     regsub {,v$} $file {} file
@@ -12,12 +14,12 @@ proc recordRCSId {variableName empty operation} {
 }
 trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
 
-set rcsId {$Id: moodss.tcl,v 1.146 1999/01/31 18:53:45 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.149 1999/02/26 21:28:11 jfontain Exp $}
 
 
 source utility.tcl
 startGatheringPackageDirectories
-set applicationVersion 6.3
+
 source getopt.tcl
 
 proc printUsage {exitCode} {
@@ -69,6 +71,7 @@ namespace import stooop::*
 if {[catch {package require switched 1.4}]} {                                           ;# in case switched package is not installed
     source switched.tcl
 }
+
 source modules.tcl
 
 if {[info exists arguments(--show-modules)]} {
@@ -76,62 +79,6 @@ if {[info exists arguments(--show-modules)]} {
     exit                                                                                                                     ;# done
 }
 
-wm command . [concat $argv0 $argv]                                   ;# for proper window manager (windowmaker for example) behavior
-wm group . .
-
-proc setPollTimes {modules {commandLineTime {}}} {                                                      ;### move to modules.tcl ###
-    global pollTimes pollTime
-
-    set default 0
-    set minimum 0
-    foreach module $modules {
-        set times [set ${module}::data(pollTimes)]
-        if {[llength $times]==0} {
-            error "module $module poll times list is empty"
-        }
-        # for an asynchronous module, the sole time value would be negative and is used as graph interval, for example
-        set time [lindex $times 0]
-        if {$time<0} {                                              ;# asynchronous module, poll time is a viewer interval (negated)
-            set intervals($time) {}
-            continue
-        }
-        if {$time>$default} {                                                                  ;# default value is the first in list
-            set default $time                                                        ;# keep the greater default time of all modules
-        }
-        set times [lsort -integer $times]                                                                         ;# sort poll times
-        set time [lindex $times 0]
-        if {$time>$minimum} {
-            set minimum $time                                                        ;# keep the greater minimum time of all modules
-            set minimumModule $module
-        }
-        foreach time $times {                                        ;# poll times list is the combination of all modules poll times
-            set data($time) {}
-        }
-    }
-    set pollTimes [lsort -integer [array names data]]         ;# sort and restrict poll times above maximum module minimum poll time
-    set pollTimes [lrange $pollTimes [lsearch -exact $pollTimes $minimum] end]
-    set pollTime $default
-    if {[string length $commandLineTime]>0} {                                           ;# eventually validate command line override
-        if {$commandLineTime<$minimum} {
-            puts stderr "$::argv0: minimum poll time is $minimum seconds for module $minimumModule"
-            exit 1
-        }
-        set pollTime $commandLineTime
-    }
-    if {$pollTime==0} { 
-        # all modules are asynchronous, so use an average time as a viewer interval for viewers that need it, such as graphs.
-        # the poll times list is empty at this point so the user cannot change the poll time.
-        # note that the viewer interval can still be forced by the command line poll time option.
-        set sum 0
-        set number 0
-        foreach interval [array names intervals] {
-            incr sum $interval
-            incr number
-        }
-        set pollTime [expr {round(double($sum)/-$number)}]
-    }
-}
-
 if {[catch {package require scwoop 2.6}]} {
     source scwoutil.tcl
     source scwoop.tcl                                                                     ;# in case scwoop package is not installed
@@ -140,43 +87,19 @@ if {[catch {package require scwoop 2.6}]} {
     source arrowbut.tcl
     source spinent.tcl
     source panner.tcl
+    source scroll.tcl
 }
-
-source record.tcl
-
-# load uninitialized modules 1st so that their tables are placed properly
-modules::initializeNext $argv                                                                                           ;# recursive
-
-if {[info exists arguments(-f)]} {                                                              ;# configuration file name specified
-    set saveFile $arguments(-f)
-    set initializer [new record -file $saveFile]
-    record::read $initializer
-    modules::initializeNext [record::modulesWithArguments $initializer]
-    set modules::(initialized) [record::modules $initializer]
-} else {
-    set saveFile {}
+if {[catch {package require tkpiechart 5.2.2}]} {                                     ;# in case tkpiechart package is not installed
+    source pielabel.tcl
+    source boxlabel.tcl
+    source canlabel.tcl
+    source labarray.tcl
+    source perilabel.tcl
+    source slice.tcl
+    source selector.tcl
+    source objselec.tcl
+    source pie.tcl
 }
-
-wm iconname . "moodss $modules::(all)"                                                            ;# give the icon a meaningful name
-set readOnly [info exists arguments(-r)]
-set static [info exists arguments(-S)]
-
-set modules::(synchronous) {}                                                                               ;# look at synchronicity
-foreach module $modules::(all) {
-    if {[lindex [set ${module}::data(pollTimes)] 0]>0} {                                                 ;# if module is synchronous
-        lappend modules::(synchronous) $module
-    }
-}
-set modules::(synchronous,string) [commaSeparatedString $modules::(synchronous)]
-
-if {[info exists arguments(-p)]} {                                                     ;# command line argument has highest priority
-    setPollTimes $modules::(all) $arguments(-p)
-} elseif {[info exists initializer]} {                                                                  ;# then stored configuration
-    setPollTimes $modules::(all) [record::pollTime $initializer]
-} else {                                                                                                       ;# use modules values
-    setPollTimes $modules::(all)
-}
-
 if {[catch {package require Tktable 2}]} {                                               ;# in case tkTable package is not installed
     switch $tcl_platform(platform) {
         unix {
@@ -187,7 +110,6 @@ if {[catch {package require Tktable 2}]} {
         }
     }
 }
-
 if {[catch {package require BLT}]} {                                                         ;# in case BLT package is not installed
     switch $tcl_platform(platform) {
         unix {
@@ -200,44 +122,107 @@ if {[catch {package require BLT}]} {
 }
 set officialBLT [expr {$blt_version!=8.0}]                                               ;# remember which BLT version is being used
 
-if {[catch {package require tkpiechart 5.2.2}]} {                                     ;# in case tkpiechart package is not installed
-    source pielabel.tcl
-    source boxlabel.tcl
-    source canlabel.tcl
-    source labarray.tcl
-    source perilabel.tcl
-    source slice.tcl
-    source selector.tcl
-    source objselec.tcl
-    source pie.tcl
-}
+wm protocol . WM_DELETE_WINDOW exit      ;# so that closing from window manager works when hung initializing a remote capable module
+wm command . [concat $argv0 $argv]                                   ;# for proper window manager (windowmaker for example) behavior
+wm group . .
 
 source config.tcl
 source font.tcl
-source scroll.tcl
 source lifolbl.tcl
-source keyslink.tcl
 source gui.tcl
-source dialog.tcl
+
+pack [createMessageWidget .] -side bottom -fill x                              ;# so that modules can display informational messages
+update
+
+wm title . {moodss: loading modules...}                   ;# load uninitialized modules 1st so that their tables are placed properly
+modules::parse $argv                                                                                                    ;# recursive
+
+source record.tcl
+
+if {[info exists arguments(-f)]} {                                                              ;# configuration file name specified
+    set saveFile $arguments(-f)
+    set initializer [new record -file $saveFile]
+    record::read $initializer
+    modules::parse [record::modulesWithArguments $initializer]
+    set modules::(initialized) [record::modules $initializer]
+} else {
+    set saveFile {}
+}
+
+wm title . {moodss: initializing modules...}
+modules::initialize                                                                            ;# with user feedback in message area
+
+source canvhand.tcl
+source canvaswm.tcl
 source viewer.tcl
 source blt2d.tcl
-source tablesel.tcl
-source datatab.tcl
-source datagraf.tcl
 source databar.tcl
+source datagraf.tcl
 source datapie.tcl
-source lastwish.tcl
 source sumtable.tcl
 source freetext.tcl
+source drag.tcl
+source drop.tcl
+
+set readOnly [info exists arguments(-r)]
+set static [info exists arguments(-S)]
+
+set scroll [new scroll canvas .]
+set canvas $composite::($scroll,scrolled,path)
+set width [winfo screenwidth .]
+set height [winfo screenheight .]
+$canvas configure -background white -width $width -height $height -scrollregion [list 0 0 $width $height] -highlightthickness 0\
+    -takefocus 0
+
+set windowManager [new canvasWindowManager $canvas]
+
+if {[info exists ::geometry]} {                                                               ;# command line geometry was specified
+    wm geometry . $::geometry
+} elseif {[info exists initializer]} {
+    foreach {width height} [record::sizes $initializer] {}                                   ;# used stored geometry for main window
+    wm geometry . ${width}x$height
+} else {
+    wm geometry . 400x300
+}
+
+wm iconname . "moodss $modules::(all)"                                                            ;# give the icon a meaningful name
+image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
+wm iconwindow . [toplevel .icon]
+pack [label .icon.image -image applicationIcon]
+
+if {!$readOnly} {
+    pack [createDragAndDropZone .] -fill x
+}
+pack $widget::($scroll,path) -fill both -expand 1
+
+set modules::(synchronous) {}                                                                               ;# look at synchronicity
+foreach module $modules::(all) {
+    if {[lindex [set ${module}::data(pollTimes)] 0]>0} {                                                 ;# if module is synchronous
+        lappend modules::(synchronous) $module
+    }
+}
+set modules::(synchronous,string) [commaSeparatedString $modules::(synchronous)]
+
+if {[info exists arguments(-p)]} {                                                     ;# command line argument has highest priority
+    modules::setPollTimes $arguments(-p)
+} elseif {[info exists initializer]} {                                                                  ;# then stored configuration
+    modules::setPollTimes [record::pollTime $initializer]
+} else {                                                                                                       ;# use modules values
+    modules::setPollTimes
+}
+
+updateTitle                                                                              ;# now that modules and poll time are known
+createMenuWidget . $readOnly [llength $pollTimes]
+
+source keyslink.tcl
+source dialog.tcl
+source tablesel.tcl
+source datatab.tcl
+source lastwish.tcl
 source htmllib.tcl                                                ;# Tcl HTML library from Sun, used for viewing HTML help documents
 source htmldata.tcl
 source html.tcl                                            ;# must be sourced after HTML library since some procedures are redefined
 source help.tcl
-source drag.tcl
-source drop.tcl
-source canvhand.tcl
-source canvaswm.tcl
-
 
 proc createCellsViewer {class cells draggable static {pollTime {}}} {
     global canvas
@@ -295,39 +280,7 @@ proc refresh {} {
     set updateEvent [after [expr {1000*$pollTime}] refresh]                                               ;# convert to milliseconds
 }
 
-createMenuWidget . $readOnly [llength $pollTimes]
-pack [createMessageWidget .] -side bottom -fill x
-updateTitle
-
-set scroll [new scroll canvas .]
-set canvas $composite::($scroll,scrolled,path)
-set width [winfo screenwidth .]
-set height [winfo screenheight .]
-$canvas configure -background white -width $width -height $height -scrollregion [list 0 0 $width $height] -highlightthickness 0\
-    -takefocus 0
-
-set windowManager [new canvasWindowManager $canvas]
-
-if {[info exists ::geometry]} {                                                               ;# command line geometry was specified
-    wm geometry . $::geometry
-} elseif {[info exists initializer]} {
-    foreach {width height} [record::sizes $initializer] {}                                   ;# used stored geometry for main window
-    wm geometry . ${width}x$height
-} else {
-    wm geometry . 400x300
-}
-
-image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
-wm iconwindow . [toplevel .icon]
-pack [label .icon.image -image applicationIcon]
-
-if {!$readOnly} {
-    pack [createDragAndDropZone .] -fill x
-}
-pack $widget::($scroll,path) -fill both -expand 1
-
 set draggable [expr {!$readOnly}]
-
 set x 0.0
 set y 0.0
 foreach module $modules::(all) {
