@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: utility.tcl,v 1.8 1999/01/17 20:13:37 jfontain Exp $}
+set rcsId {$Id: utility.tcl,v 1.9 1999/01/26 20:32:25 jfontain Exp $}
 
 proc minimum {a b} {return [expr {$a<$b?$a:$b}]}
 proc maximum {a b} {return [expr {$a>$b?$a:$b}]}
@@ -17,16 +17,6 @@ proc ldelete {listName value} {
 
 }
 
-proc startGatheringRCSIds {} {
-    trace variable ::rcsId w recordRCSId
-}
-
-proc recordRCSId {variableName empty operation} {
-    foreach {header file version} $::rcsId break
-    regsub {,v$} $file {} file
-    set ::sourceVersion($file) $version
-}
-
 proc commaSeparatedString {words} {
     for {set index 0} {$index<([llength $words]-1)} {incr index} {
         append string "[lindex $words $index], "
